Skip to contents

Creates a visualization of the summary metric for systematic trends. Values close to 0 indicate strong evidence of trend, values close to 1 indicate no evidence.

Usage

plot_smoothing_summary(
  smoothing_results,
  x_lab = NULL,
  y_lab = "Probability",
  title = "Prob(residual trend does not deviate from zero)",
  subtitle = "Black line = probability. Red dashed line indicates 0.1 threshold."
)

Arguments

smoothing_results

Output from residual_model_check()

x_lab

Label for x-axis (default: NULL, uses predictor name)

y_lab

Label for y-axis

title

Plot title

subtitle

Plot subtitle

Value

A ggplot object