Plot summary metric for systematic trends
Source:R/residual_model_check.R
plot_smoothing_summary.RdCreates a visualization of the summary metric for systematic trends. Values close to 0 indicate strong evidence of trend, values close to 1 indicate no evidence.
Usage
plot_smoothing_summary(
smoothing_results,
x_lab = NULL,
y_lab = "Probability",
title = "Prob(residual trend does not deviate from zero)",
subtitle = "Black line = probability. Red dashed line indicates 0.1 threshold."
)